# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import auth modules into client package
from .auth.oauth import Account
from .auth.oauth import Organization
from .auth.oauth import Link
from .auth.oauth import OAuth
from .auth.oauth import OAuthToken
from .auth.oauth import OAuthUserInfo



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
            self.trace_token = http_resp.getheader('X-DocuSign-TraceToken')
            self.timestamp = http_resp.getheader('date')
            self.response = http_resp
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """
        Custom error messages for exception
        """
        error_message = "({0})\n" \
                        "Reason: {1}\n" \
                        "Trace-Token: {2}\n" \
                        "Timestamp: {3}\n".format(self.status, self.reason, self.trace_token, self.timestamp)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


class ArgumentException(Exception):

    def __init__(self, *args, **kwargs):
        if not args:
            super().__init__("argument cannot be empty")
        else:
            super().__init__(*args, **kwargs)


class InvalidBasePath(Exception):
    pass



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class WorkflowStepHistory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'dac_id': 'str',
        'ds_step_id': 'str',
        'end_date': 'datetime',
        'error': 'WorkflowStepError',
        'output_module_properties': 'object',
        'start_date': 'datetime',
        'step_id': 'str',
        'step_name': 'str',
        'step_state': 'WorkflowStepHistoryState',
        'user_id': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'dac_id': 'dacId',
        'ds_step_id': 'dsStepId',
        'end_date': 'endDate',
        'error': 'error',
        'output_module_properties': 'outputModuleProperties',
        'start_date': 'startDate',
        'step_id': 'stepId',
        'step_name': 'stepName',
        'step_state': 'stepState',
        'user_id': 'userId'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """WorkflowStepHistory - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._dac_id = None
        self._ds_step_id = None
        self._end_date = None
        self._error = None
        self._output_module_properties = None
        self._start_date = None
        self._step_id = None
        self._step_name = None
        self._step_state = None
        self._user_id = None
        self.discriminator = None

        setattr(self, "_{}".format('account_id'), kwargs.get('account_id', None))
        setattr(self, "_{}".format('dac_id'), kwargs.get('dac_id', None))
        setattr(self, "_{}".format('ds_step_id'), kwargs.get('ds_step_id', None))
        setattr(self, "_{}".format('end_date'), kwargs.get('end_date', None))
        setattr(self, "_{}".format('error'), kwargs.get('error', None))
        setattr(self, "_{}".format('output_module_properties'), kwargs.get('output_module_properties', None))
        setattr(self, "_{}".format('start_date'), kwargs.get('start_date', None))
        setattr(self, "_{}".format('step_id'), kwargs.get('step_id', None))
        setattr(self, "_{}".format('step_name'), kwargs.get('step_name', None))
        setattr(self, "_{}".format('step_state'), kwargs.get('step_state', None))
        setattr(self, "_{}".format('user_id'), kwargs.get('user_id', None))

    @property
    def account_id(self):
        """Gets the account_id of this WorkflowStepHistory.  # noqa: E501


        :return: The account_id of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WorkflowStepHistory.


        :param account_id: The account_id of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def dac_id(self):
        """Gets the dac_id of this WorkflowStepHistory.  # noqa: E501


        :return: The dac_id of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._dac_id

    @dac_id.setter
    def dac_id(self, dac_id):
        """Sets the dac_id of this WorkflowStepHistory.


        :param dac_id: The dac_id of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and dac_id is None:
            raise ValueError("Invalid value for `dac_id`, must not be `None`")  # noqa: E501

        self._dac_id = dac_id

    @property
    def ds_step_id(self):
        """Gets the ds_step_id of this WorkflowStepHistory.  # noqa: E501


        :return: The ds_step_id of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._ds_step_id

    @ds_step_id.setter
    def ds_step_id(self, ds_step_id):
        """Sets the ds_step_id of this WorkflowStepHistory.


        :param ds_step_id: The ds_step_id of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """

        self._ds_step_id = ds_step_id

    @property
    def end_date(self):
        """Gets the end_date of this WorkflowStepHistory.  # noqa: E501

        Track the End time of the Workflow Step  # noqa: E501

        :return: The end_date of this WorkflowStepHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this WorkflowStepHistory.

        Track the End time of the Workflow Step  # noqa: E501

        :param end_date: The end_date of this WorkflowStepHistory.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def error(self):
        """Gets the error of this WorkflowStepHistory.  # noqa: E501


        :return: The error of this WorkflowStepHistory.  # noqa: E501
        :rtype: WorkflowStepError
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this WorkflowStepHistory.


        :param error: The error of this WorkflowStepHistory.  # noqa: E501
        :type: WorkflowStepError
        """

        self._error = error

    @property
    def output_module_properties(self):
        """Gets the output_module_properties of this WorkflowStepHistory.  # noqa: E501


        :return: The output_module_properties of this WorkflowStepHistory.  # noqa: E501
        :rtype: object
        """
        return self._output_module_properties

    @output_module_properties.setter
    def output_module_properties(self, output_module_properties):
        """Sets the output_module_properties of this WorkflowStepHistory.


        :param output_module_properties: The output_module_properties of this WorkflowStepHistory.  # noqa: E501
        :type: object
        """

        self._output_module_properties = output_module_properties

    @property
    def start_date(self):
        """Gets the start_date of this WorkflowStepHistory.  # noqa: E501

        Track the Start time of the Workflow Step  # noqa: E501

        :return: The start_date of this WorkflowStepHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this WorkflowStepHistory.

        Track the Start time of the Workflow Step  # noqa: E501

        :param start_date: The start_date of this WorkflowStepHistory.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def step_id(self):
        """Gets the step_id of this WorkflowStepHistory.  # noqa: E501

        The Step Id of the workflow step in the workflow instance  # noqa: E501

        :return: The step_id of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """Sets the step_id of this WorkflowStepHistory.

        The Step Id of the workflow step in the workflow instance  # noqa: E501

        :param step_id: The step_id of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """

        self._step_id = step_id

    @property
    def step_name(self):
        """Gets the step_name of this WorkflowStepHistory.  # noqa: E501

        Name of the workflow step (DS Scope)  # noqa: E501

        :return: The step_name of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._step_name

    @step_name.setter
    def step_name(self, step_name):
        """Sets the step_name of this WorkflowStepHistory.

        Name of the workflow step (DS Scope)  # noqa: E501

        :param step_name: The step_name of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and step_name is None:
            raise ValueError("Invalid value for `step_name`, must not be `None`")  # noqa: E501

        self._step_name = step_name

    @property
    def step_state(self):
        """Gets the step_state of this WorkflowStepHistory.  # noqa: E501


        :return: The step_state of this WorkflowStepHistory.  # noqa: E501
        :rtype: WorkflowStepHistoryState
        """
        return self._step_state

    @step_state.setter
    def step_state(self, step_state):
        """Sets the step_state of this WorkflowStepHistory.


        :param step_state: The step_state of this WorkflowStepHistory.  # noqa: E501
        :type: WorkflowStepHistoryState
        """
        if self._configuration.client_side_validation and step_state is None:
            raise ValueError("Invalid value for `step_state`, must not be `None`")  # noqa: E501

        self._step_state = step_state

    @property
    def user_id(self):
        """Gets the user_id of this WorkflowStepHistory.  # noqa: E501


        :return: The user_id of this WorkflowStepHistory.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WorkflowStepHistory.


        :param user_id: The user_id of this WorkflowStepHistory.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowStepHistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowStepHistory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowStepHistory):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class ESignDocumentFromPreviousStep(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_from_previous_step': 'object',
        'file_extension': 'DSWorkflowDocGenDocOutputFormat',
        'name': 'object',
        'type': 'ESignDocumentTypesFromPreviousStep'
    }

    attribute_map = {
        'document_from_previous_step': 'documentFromPreviousStep',
        'file_extension': 'fileExtension',
        'name': 'name',
        'type': 'type'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """ESignDocumentFromPreviousStep - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._document_from_previous_step = None
        self._file_extension = None
        self._name = None
        self._type = None
        self.discriminator = None

        setattr(self, "_{}".format('document_from_previous_step'), kwargs.get('document_from_previous_step', None))
        setattr(self, "_{}".format('file_extension'), kwargs.get('file_extension', None))
        setattr(self, "_{}".format('name'), kwargs.get('name', None))
        setattr(self, "_{}".format('type'), kwargs.get('type', None))

    @property
    def document_from_previous_step(self):
        """Gets the document_from_previous_step of this ESignDocumentFromPreviousStep.  # noqa: E501

        Reference of #/definitions/DSWorkflowVariable. DS Workflow Variables  # noqa: E501

        :return: The document_from_previous_step of this ESignDocumentFromPreviousStep.  # noqa: E501
        :rtype: object
        """
        return self._document_from_previous_step

    @document_from_previous_step.setter
    def document_from_previous_step(self, document_from_previous_step):
        """Sets the document_from_previous_step of this ESignDocumentFromPreviousStep.

        Reference of #/definitions/DSWorkflowVariable. DS Workflow Variables  # noqa: E501

        :param document_from_previous_step: The document_from_previous_step of this ESignDocumentFromPreviousStep.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and document_from_previous_step is None:
            raise ValueError("Invalid value for `document_from_previous_step`, must not be `None`")  # noqa: E501

        self._document_from_previous_step = document_from_previous_step

    @property
    def file_extension(self):
        """Gets the file_extension of this ESignDocumentFromPreviousStep.  # noqa: E501


        :return: The file_extension of this ESignDocumentFromPreviousStep.  # noqa: E501
        :rtype: DSWorkflowDocGenDocOutputFormat
        """
        return self._file_extension

    @file_extension.setter
    def file_extension(self, file_extension):
        """Sets the file_extension of this ESignDocumentFromPreviousStep.


        :param file_extension: The file_extension of this ESignDocumentFromPreviousStep.  # noqa: E501
        :type: DSWorkflowDocGenDocOutputFormat
        """
        if self._configuration.client_side_validation and file_extension is None:
            raise ValueError("Invalid value for `file_extension`, must not be `None`")  # noqa: E501

        self._file_extension = file_extension

    @property
    def name(self):
        """Gets the name of this ESignDocumentFromPreviousStep.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The name of this ESignDocumentFromPreviousStep.  # noqa: E501
        :rtype: object
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ESignDocumentFromPreviousStep.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param name: The name of this ESignDocumentFromPreviousStep.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this ESignDocumentFromPreviousStep.  # noqa: E501


        :return: The type of this ESignDocumentFromPreviousStep.  # noqa: E501
        :rtype: ESignDocumentTypesFromPreviousStep
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ESignDocumentFromPreviousStep.


        :param type: The type of this ESignDocumentFromPreviousStep.  # noqa: E501
        :type: ESignDocumentTypesFromPreviousStep
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ESignDocumentFromPreviousStep, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ESignDocumentFromPreviousStep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ESignDocumentFromPreviousStep):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class ESignTabs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'anchor_string': 'str',
        'bold': 'str',
        'document_id': 'str',
        'font': 'str',
        'font_color': 'str',
        'font_size': 'str',
        'height': 'str',
        'italic': 'str',
        'locale_policy': 'dict(str, object)',
        'name': 'str',
        'optional': 'str',
        'page_number': 'str',
        'recipient_id': 'str',
        'scale_value': 'str',
        'stamp_type': 'str',
        'tab_id': 'str',
        'tab_label': 'str',
        'tab_type': 'str',
        'template_locked': 'str',
        'template_required': 'str',
        'tooltip': 'str',
        'underline': 'str',
        'value': 'object',
        'width': 'str',
        'x_position': 'str',
        'y_position': 'str'
    }

    attribute_map = {
        'anchor_string': 'anchorString',
        'bold': 'bold',
        'document_id': 'documentId',
        'font': 'font',
        'font_color': 'fontColor',
        'font_size': 'fontSize',
        'height': 'height',
        'italic': 'italic',
        'locale_policy': 'localePolicy',
        'name': 'name',
        'optional': 'optional',
        'page_number': 'pageNumber',
        'recipient_id': 'recipientId',
        'scale_value': 'scaleValue',
        'stamp_type': 'stampType',
        'tab_id': 'tabId',
        'tab_label': 'tabLabel',
        'tab_type': 'tabType',
        'template_locked': 'templateLocked',
        'template_required': 'templateRequired',
        'tooltip': 'tooltip',
        'underline': 'underline',
        'value': 'value',
        'width': 'width',
        'x_position': 'xPosition',
        'y_position': 'yPosition'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """ESignTabs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._anchor_string = None
        self._bold = None
        self._document_id = None
        self._font = None
        self._font_color = None
        self._font_size = None
        self._height = None
        self._italic = None
        self._locale_policy = None
        self._name = None
        self._optional = None
        self._page_number = None
        self._recipient_id = None
        self._scale_value = None
        self._stamp_type = None
        self._tab_id = None
        self._tab_label = None
        self._tab_type = None
        self._template_locked = None
        self._template_required = None
        self._tooltip = None
        self._underline = None
        self._value = None
        self._width = None
        self._x_position = None
        self._y_position = None
        self.discriminator = None

        setattr(self, "_{}".format('anchor_string'), kwargs.get('anchor_string', None))
        setattr(self, "_{}".format('bold'), kwargs.get('bold', None))
        setattr(self, "_{}".format('document_id'), kwargs.get('document_id', None))
        setattr(self, "_{}".format('font'), kwargs.get('font', None))
        setattr(self, "_{}".format('font_color'), kwargs.get('font_color', None))
        setattr(self, "_{}".format('font_size'), kwargs.get('font_size', None))
        setattr(self, "_{}".format('height'), kwargs.get('height', None))
        setattr(self, "_{}".format('italic'), kwargs.get('italic', None))
        setattr(self, "_{}".format('locale_policy'), kwargs.get('locale_policy', None))
        setattr(self, "_{}".format('name'), kwargs.get('name', None))
        setattr(self, "_{}".format('optional'), kwargs.get('optional', None))
        setattr(self, "_{}".format('page_number'), kwargs.get('page_number', None))
        setattr(self, "_{}".format('recipient_id'), kwargs.get('recipient_id', None))
        setattr(self, "_{}".format('scale_value'), kwargs.get('scale_value', None))
        setattr(self, "_{}".format('stamp_type'), kwargs.get('stamp_type', None))
        setattr(self, "_{}".format('tab_id'), kwargs.get('tab_id', None))
        setattr(self, "_{}".format('tab_label'), kwargs.get('tab_label', None))
        setattr(self, "_{}".format('tab_type'), kwargs.get('tab_type', None))
        setattr(self, "_{}".format('template_locked'), kwargs.get('template_locked', None))
        setattr(self, "_{}".format('template_required'), kwargs.get('template_required', None))
        setattr(self, "_{}".format('tooltip'), kwargs.get('tooltip', None))
        setattr(self, "_{}".format('underline'), kwargs.get('underline', None))
        setattr(self, "_{}".format('value'), kwargs.get('value', None))
        setattr(self, "_{}".format('width'), kwargs.get('width', None))
        setattr(self, "_{}".format('x_position'), kwargs.get('x_position', None))
        setattr(self, "_{}".format('y_position'), kwargs.get('y_position', None))

    @property
    def anchor_string(self):
        """Gets the anchor_string of this ESignTabs.  # noqa: E501


        :return: The anchor_string of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._anchor_string

    @anchor_string.setter
    def anchor_string(self, anchor_string):
        """Sets the anchor_string of this ESignTabs.


        :param anchor_string: The anchor_string of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._anchor_string = anchor_string

    @property
    def bold(self):
        """Gets the bold of this ESignTabs.  # noqa: E501


        :return: The bold of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this ESignTabs.


        :param bold: The bold of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._bold = bold

    @property
    def document_id(self):
        """Gets the document_id of this ESignTabs.  # noqa: E501


        :return: The document_id of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this ESignTabs.


        :param document_id: The document_id of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def font(self):
        """Gets the font of this ESignTabs.  # noqa: E501


        :return: The font of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._font

    @font.setter
    def font(self, font):
        """Sets the font of this ESignTabs.


        :param font: The font of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._font = font

    @property
    def font_color(self):
        """Gets the font_color of this ESignTabs.  # noqa: E501


        :return: The font_color of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._font_color

    @font_color.setter
    def font_color(self, font_color):
        """Sets the font_color of this ESignTabs.


        :param font_color: The font_color of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._font_color = font_color

    @property
    def font_size(self):
        """Gets the font_size of this ESignTabs.  # noqa: E501


        :return: The font_size of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """Sets the font_size of this ESignTabs.


        :param font_size: The font_size of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._font_size = font_size

    @property
    def height(self):
        """Gets the height of this ESignTabs.  # noqa: E501


        :return: The height of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this ESignTabs.


        :param height: The height of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._height = height

    @property
    def italic(self):
        """Gets the italic of this ESignTabs.  # noqa: E501


        :return: The italic of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """Sets the italic of this ESignTabs.


        :param italic: The italic of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._italic = italic

    @property
    def locale_policy(self):
        """Gets the locale_policy of this ESignTabs.  # noqa: E501


        :return: The locale_policy of this ESignTabs.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._locale_policy

    @locale_policy.setter
    def locale_policy(self, locale_policy):
        """Sets the locale_policy of this ESignTabs.


        :param locale_policy: The locale_policy of this ESignTabs.  # noqa: E501
        :type: dict(str, object)
        """

        self._locale_policy = locale_policy

    @property
    def name(self):
        """Gets the name of this ESignTabs.  # noqa: E501


        :return: The name of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ESignTabs.


        :param name: The name of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def optional(self):
        """Gets the optional of this ESignTabs.  # noqa: E501


        :return: The optional of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._optional

    @optional.setter
    def optional(self, optional):
        """Sets the optional of this ESignTabs.


        :param optional: The optional of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._optional = optional

    @property
    def page_number(self):
        """Gets the page_number of this ESignTabs.  # noqa: E501


        :return: The page_number of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this ESignTabs.


        :param page_number: The page_number of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._page_number = page_number

    @property
    def recipient_id(self):
        """Gets the recipient_id of this ESignTabs.  # noqa: E501


        :return: The recipient_id of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._recipient_id

    @recipient_id.setter
    def recipient_id(self, recipient_id):
        """Sets the recipient_id of this ESignTabs.


        :param recipient_id: The recipient_id of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._recipient_id = recipient_id

    @property
    def scale_value(self):
        """Gets the scale_value of this ESignTabs.  # noqa: E501


        :return: The scale_value of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._scale_value

    @scale_value.setter
    def scale_value(self, scale_value):
        """Sets the scale_value of this ESignTabs.


        :param scale_value: The scale_value of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._scale_value = scale_value

    @property
    def stamp_type(self):
        """Gets the stamp_type of this ESignTabs.  # noqa: E501


        :return: The stamp_type of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._stamp_type

    @stamp_type.setter
    def stamp_type(self, stamp_type):
        """Sets the stamp_type of this ESignTabs.


        :param stamp_type: The stamp_type of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._stamp_type = stamp_type

    @property
    def tab_id(self):
        """Gets the tab_id of this ESignTabs.  # noqa: E501


        :return: The tab_id of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._tab_id

    @tab_id.setter
    def tab_id(self, tab_id):
        """Sets the tab_id of this ESignTabs.


        :param tab_id: The tab_id of this ESignTabs.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and tab_id is None:
            raise ValueError("Invalid value for `tab_id`, must not be `None`")  # noqa: E501

        self._tab_id = tab_id

    @property
    def tab_label(self):
        """Gets the tab_label of this ESignTabs.  # noqa: E501


        :return: The tab_label of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._tab_label

    @tab_label.setter
    def tab_label(self, tab_label):
        """Sets the tab_label of this ESignTabs.


        :param tab_label: The tab_label of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._tab_label = tab_label

    @property
    def tab_type(self):
        """Gets the tab_type of this ESignTabs.  # noqa: E501


        :return: The tab_type of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._tab_type

    @tab_type.setter
    def tab_type(self, tab_type):
        """Sets the tab_type of this ESignTabs.


        :param tab_type: The tab_type of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._tab_type = tab_type

    @property
    def template_locked(self):
        """Gets the template_locked of this ESignTabs.  # noqa: E501


        :return: The template_locked of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._template_locked

    @template_locked.setter
    def template_locked(self, template_locked):
        """Sets the template_locked of this ESignTabs.


        :param template_locked: The template_locked of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._template_locked = template_locked

    @property
    def template_required(self):
        """Gets the template_required of this ESignTabs.  # noqa: E501


        :return: The template_required of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._template_required

    @template_required.setter
    def template_required(self, template_required):
        """Sets the template_required of this ESignTabs.


        :param template_required: The template_required of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._template_required = template_required

    @property
    def tooltip(self):
        """Gets the tooltip of this ESignTabs.  # noqa: E501


        :return: The tooltip of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._tooltip

    @tooltip.setter
    def tooltip(self, tooltip):
        """Sets the tooltip of this ESignTabs.


        :param tooltip: The tooltip of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._tooltip = tooltip

    @property
    def underline(self):
        """Gets the underline of this ESignTabs.  # noqa: E501


        :return: The underline of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """Sets the underline of this ESignTabs.


        :param underline: The underline of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._underline = underline

    @property
    def value(self):
        """Gets the value of this ESignTabs.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The value of this ESignTabs.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ESignTabs.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param value: The value of this ESignTabs.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def width(self):
        """Gets the width of this ESignTabs.  # noqa: E501


        :return: The width of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ESignTabs.


        :param width: The width of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._width = width

    @property
    def x_position(self):
        """Gets the x_position of this ESignTabs.  # noqa: E501


        :return: The x_position of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._x_position

    @x_position.setter
    def x_position(self, x_position):
        """Sets the x_position of this ESignTabs.


        :param x_position: The x_position of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._x_position = x_position

    @property
    def y_position(self):
        """Gets the y_position of this ESignTabs.  # noqa: E501


        :return: The y_position of this ESignTabs.  # noqa: E501
        :rtype: str
        """
        return self._y_position

    @y_position.setter
    def y_position(self, y_position):
        """Sets the y_position of this ESignTabs.


        :param y_position: The y_position of this ESignTabs.  # noqa: E501
        :type: str
        """

        self._y_position = y_position

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ESignTabs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ESignTabs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ESignTabs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DSWorkflowVariableFromStep(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'property_name': 'str',
        'source': 'DSWorkflowVariableSourceTypesStep',
        'step_id': 'str'
    }

    attribute_map = {
        'key': 'key',
        'property_name': 'propertyName',
        'source': 'source',
        'step_id': 'stepId'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DSWorkflowVariableFromStep - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key = None
        self._property_name = None
        self._source = None
        self._step_id = None
        self.discriminator = None

        setattr(self, "_{}".format('key'), kwargs.get('key', None))
        setattr(self, "_{}".format('property_name'), kwargs.get('property_name', None))
        setattr(self, "_{}".format('source'), kwargs.get('source', None))
        setattr(self, "_{}".format('step_id'), kwargs.get('step_id', None))

    @property
    def key(self):
        """Gets the key of this DSWorkflowVariableFromStep.  # noqa: E501


        :return: The key of this DSWorkflowVariableFromStep.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DSWorkflowVariableFromStep.


        :param key: The key of this DSWorkflowVariableFromStep.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def property_name(self):
        """Gets the property_name of this DSWorkflowVariableFromStep.  # noqa: E501


        :return: The property_name of this DSWorkflowVariableFromStep.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this DSWorkflowVariableFromStep.


        :param property_name: The property_name of this DSWorkflowVariableFromStep.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def source(self):
        """Gets the source of this DSWorkflowVariableFromStep.  # noqa: E501


        :return: The source of this DSWorkflowVariableFromStep.  # noqa: E501
        :rtype: DSWorkflowVariableSourceTypesStep
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DSWorkflowVariableFromStep.


        :param source: The source of this DSWorkflowVariableFromStep.  # noqa: E501
        :type: DSWorkflowVariableSourceTypesStep
        """
        if self._configuration.client_side_validation and source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def step_id(self):
        """Gets the step_id of this DSWorkflowVariableFromStep.  # noqa: E501


        :return: The step_id of this DSWorkflowVariableFromStep.  # noqa: E501
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """Sets the step_id of this DSWorkflowVariableFromStep.


        :param step_id: The step_id of this DSWorkflowVariableFromStep.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and step_id is None:
            raise ValueError("Invalid value for `step_id`, must not be `None`")  # noqa: E501

        self._step_id = step_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DSWorkflowVariableFromStep, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DSWorkflowVariableFromStep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DSWorkflowVariableFromStep):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import re
import json
import mimetypes
import tempfile
import threading
import base64
import math
import jwt

from datetime import date, datetime
from time import time

# python 2 and python 3 compatibility library
from six import PY3, integer_types, iteritems, text_type
from six.moves.urllib.parse import quote

from docusign_maestro import client
from docusign_maestro import models

from .configuration import Configuration
from .api_exception import ApiException, ArgumentException
from .api_response import RESTClientObject, RESTResponse
from .auth.oauth import OAuthUserInfo, OAuthToken, OAuth, Account, Organization, Link

class ApiClient(object):
    """
    Generic API client for Swagger client library builds.

    Swagger generic API client. This client handles the client-
    server communication, and is invariant across implementations. Specifics of
    the methods and models for each application are generated from the Swagger
    templates.

    NOTE: This class is auto generated by the swagger code generator program.
    Ref: https://github.com/swagger-api/swagger-codegen
    Do not edit the class manually.

    :param host: The base path for the server to call.
    :param header_name: a header to pass when making calls to the API.
    :param header_value: a header value to pass when making calls to the API.
    """

    PRIMITIVE_TYPES = (float, bool, bytes, text_type) + integer_types
    NATIVE_TYPES_MAPPING = {
        'int': int,
        'long': int if PY3 else long,
        'float': float,
        'str': str,
        'bool': bool,
        'date': date,
        'datetime': datetime,
        'object': object,
    }

    OAUTH_TYPES = (OAuthToken.__name__, OAuthUserInfo.__name__, Account.__name__, Organization.__name__, Link.__name__)

    def __init__(self, host=None, header_name=None, header_value=None, cookie=None, oauth_host_name=None, base_path=None):
        """
        Constructor of the class.
        """

        config = Configuration()
        self.rest_client = RESTClientObject(configuration=config)
        self.default_headers = {'X-DocuSign-SDK': 'Python'}
        if header_name is not None:
            self.default_headers[header_name] = header_value
        if host is None:
            self.host = config.host
        elif host == "":
            raise ArgumentException("basePath cannot be empty")
        else:
            self.host = host

        self.cookie = cookie
        self.base_path = base_path
        self.set_oauth_host_name(oauth_host_name)

        # Set default User-Agent.
        self.user_agent = config.user_agent

    @property
    def user_agent(self):
        """
        Gets user agent.
        """
        return self.default_headers['User-Agent']

    @user_agent.setter
    def user_agent(self, value):
        """
        Sets user agent.
        """
        self.default_headers['User-Agent'] = value

    def set_default_header(self, header_name, header_value):
        self.default_headers[header_name] = header_value

    def __call_api(self, resource_path, method,
                   path_params=None, query_params=None, header_params=None,
                   body=None, post_params=None, files=None,
                   response_type=None, auth_settings=None, callback=None,
                   _return_http_data_only=None, collection_formats=None, _preload_content=True,
                   _request_timeout=None):
        """
        :param _preload_content: if False, the urllib3.HTTPResponse object will be returned without
                                 reading/decoding response data. Default is True. 
        :return: 
        """

        # header parameters
        header_params = header_params or {}
        header_params.update(self.default_headers)
        if self.cookie:
            header_params['Cookie'] = self.cookie
        if header_params:
            header_params = self.sanitize_for_serialization(header_params)
            header_params = dict(self.parameters_to_tuples(header_params,
                                                           collection_formats))

        # path parameters
        if path_params:
            path_params = self.sanitize_for_serialization(path_params)
            path_params = self.parameters_to_tuples(path_params,
                                                    collection_formats)
            for k, v in path_params:
                resource_path = resource_path.replace(
                    '{%s}' % k, quote(str(v), safe=""))

        # query parameters
        if query_params:
            query_params = self.sanitize_for_serialization(query_params)
            query_params = self.parameters_to_tuples(query_params,
                                                     collection_formats)

        # post parameters
        if post_params or files:
            post_params = self.prepare_post_parameters(post_params, files)
            post_params = self.sanitize_for_serialization(post_params)
            post_params = self.parameters_to_tuples(post_params,
                                                    collection_formats)

        # auth setting
        self.update_params_for_auth(header_params, query_params, auth_settings)

        # body
        if body:
            body = self.sanitize_for_serialization(body)

        # request url
        url = self.host + resource_path

        # perform request and return response
        response_data = self.request(method, url,
                                     query_params=query_params,
                                     headers=header_params,
                                     post_params=post_params, body=body,
                                     _preload_content=_preload_content,
                                     _request_timeout=_request_timeout)

        self.last_response = response_data

        return_data = response_data
        if _preload_content:
            r = RESTResponse(response_data)

            # deserialize response data
            if response_type:
                # In the python 3, the response.data is bytes.
                # we need to decode it to string.
                if PY3 and response_type != "file":
                    try:
                        r.data = r.data.decode('utf8', 'replace')
                    except (UnicodeDecodeError, AttributeError):
                        pass
                return_data = self.deserialize(r, response_type)
            else:
                return_data = None

        if callback:
            if _return_http_data_only:
                callback(return_data)
            else:
                callback((return_data, response_data.status, response_data.getheaders()))
        elif _return_http_data_only:
            return (return_data)
        else:
            return (return_data, response_data.status, response_data.getheaders())

    def sanitize_for_serialization(self, obj):
        """
        Builds a JSON POST object.

        If obj is None, return None.
        If obj is str, int, long, float, bool, return directly.
        If obj is datetime.datetime, datetime.date
            convert to string in iso8601 format.
        If obj is list, sanitize each element in the list.
        If obj is dict, return the dict.
        If obj is swagger model, return the properties dict.

        :param obj: The data to serialize.
        :return: The serialized form of data.
        """
        if obj is None:
            return None
        elif isinstance(obj, self.PRIMITIVE_TYPES):
            return obj
        elif isinstance(obj, list):
            return [self.sanitize_for_serialization(sub_obj)
                    for sub_obj in obj]
        elif isinstance(obj, tuple):
            return tuple(self.sanitize_for_serialization(sub_obj)
                         for sub_obj in obj)
        elif isinstance(obj, (datetime, date)):
            return obj.isoformat()

        if isinstance(obj, dict):
            obj_dict = obj
        else:
            # Convert model obj to dict except
            # attributes `swagger_types`, `attribute_map`
            # and attributes which value is not None.
            # Convert attribute name to json key in
            # model definition for request.
            obj_dict = {obj.attribute_map[attr]: getattr(obj, attr)
                        for attr, _ in iteritems(obj.swagger_types)
                        if getattr(obj, attr) is not None}

        return {key: self.sanitize_for_serialization(val)
                for key, val in iteritems(obj_dict)}

    def deserialize(self, response, response_type):
        """
        Deserializes response into an object.

        :param response: RESTResponse object to be deserialized.
        :param response_type: class literal for
            deserialized object, or string of class name.

        :return: deserialized object.
        """
        # handle file downloading
        # save response body into a tmp file and return the instance
        if response_type == "file":
            return self.__deserialize_file(response)

        # fetch data from response object
        try:
            data = json.loads(response.data)
        except ValueError:
            data = response.data

        return self.__deserialize(data, response_type)

    def __deserialize(self, data, klass):
        """
        Deserializes dict, list, str into an object.

        :param data: dict, list or str.
        :param klass: class literal, or string of class name.

        :return: object.
        """
        if data is None:
            return None

        if type(klass) == str:
            if klass.startswith('list['):
                sub_kls = re.match('list\[(.*)\]', klass).group(1)
                return [self.__deserialize(sub_data, sub_kls)
                        for sub_data in data]

            if klass.startswith('dict('):
                sub_kls = re.match('dict\(([^,]*), (.*)\)', klass).group(2)
                return {k: self.__deserialize(v, sub_kls)
                        for k, v in iteritems(data)}

            # convert str to class
            if klass in self.NATIVE_TYPES_MAPPING:
                klass = self.NATIVE_TYPES_MAPPING[klass]
            else:
                if klass in self.OAUTH_TYPES:
                    klass = getattr(client, klass)
                else:
                    klass = getattr(models, klass)

        if klass in self.PRIMITIVE_TYPES:
            return self.__deserialize_primitive(data, klass)
        elif klass == object:
            return self.__deserialize_object(data)
        elif klass == date:
            return self.__deserialize_date(data)
        elif klass == datetime:
            return self.__deserialize_datatime(data)
        else:
            return self.__deserialize_model(data, klass)

    def call_api(self, resource_path, method,
                 path_params=None, query_params=None, header_params=None,
                 body=None, post_params=None, files=None,
                 response_type=None, auth_settings=None, callback=None,
                 _return_http_data_only=None, collection_formats=None, _preload_content=True,
                 _request_timeout=None):
        """
        Makes the HTTP request (synchronous) and return the deserialized data.
        To make an async request, define a function for callback.

        :param resource_path: Path to method endpoint.
        :param method: Method to call.
        :param path_params: Path parameters in the url.
        :param query_params: Query parameters in the url.
        :param header_params: Header parameters to be
            placed in the request header.
        :param body: Request body.
        :param post_params dict: Request post form parameters,
            for `application/x-www-form-urlencoded`, `multipart/form-data`.
        :param auth_settings list: Auth Settings names for the request.
        :param response: Response data type.
        :param files dict: key -> filename, value -> filepath,
            for `multipart/form-data`.
        :param callback function: Callback function for asynchronous request.
            If provide this parameter,
            the request will be called asynchronously.
        :param _return_http_data_only: response data without head status code and headers
        :param collection_formats: dict of collection formats for path, query,
            header, and post parameters.
        :param _preload_content: if False, the urllib3.HTTPResponse object will be returned without
                                 reading/decoding response data. Default is True.
        :param _request_timeout: timeout setting for this request. If one number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of (connection, read) timeouts.
        :return:
            If provide parameter callback,
            the request will be called asynchronously.
            The method will return the request thread.
            If parameter callback is None,
            then the method will return the response directly.
        """
        if callback is None:
            return self.__call_api(resource_path, method,
                                   path_params, query_params, header_params,
                                   body, post_params, files,
                                   response_type, auth_settings, callback,
                                   _return_http_data_only, collection_formats, _preload_content, _request_timeout)
        else:
            thread = threading.Thread(target=self.__call_api,
                                      args=(resource_path, method,
                                            path_params, query_params,
                                            header_params, body,
                                            post_params, files,
                                            response_type, auth_settings,
                                            callback, _return_http_data_only,
                                            collection_formats, _preload_content, _request_timeout))
        thread.start()
        return thread

    def request(self, method, url, query_params=None, headers=None,
                post_params=None, body=None, _preload_content=True, _request_timeout=None):
        """
        Makes the HTTP request using RESTClient.
        """
        if method == "GET":
            return self.rest_client.GET(url,
                                        query_params=query_params,
                                        _preload_content=_preload_content,
                                        _request_timeout=_request_timeout,
                                        headers=headers)
        elif method == "HEAD":
            return self.rest_client.HEAD(url,
                                         query_params=query_params,
                                         _preload_content=_preload_content,
                                         _request_timeout=_request_timeout,
                                         headers=headers)
        elif method == "OPTIONS":
            return self.rest_client.OPTIONS(url,
                                            query_params=query_params,
                                            headers=headers,
                                            post_params=post_params,
                                            _preload_content=_preload_content,
                                            _request_timeout=_request_timeout,
                                            body=body)
        elif method == "POST":
            return self.rest_client.POST(url,
                                         query_params=query_params,
                                         headers=headers,
                                         post_params=post_params,
                                         _preload_content=_preload_content,
                                         _request_timeout=_request_timeout,
                                         body=body)
        elif method == "PUT":
            return self.rest_client.PUT(url,
                                        query_params=query_params,
                                        headers=headers,
                                        post_params=post_params,
                                        _preload_content=_preload_content,
                                        _request_timeout=_request_timeout,
                                        body=body)
        elif method == "PATCH":
            return self.rest_client.PATCH(url,
                                          query_params=query_params,
                                          headers=headers,
                                          post_params=post_params,
                                          _preload_content=_preload_content,
                                          _request_timeout=_request_timeout,
                                          body=body)
        elif method == "DELETE":
            return self.rest_client.DELETE(url,
                                           query_params=query_params,
                                           headers=headers,
                                           _preload_content=_preload_content,
                                           _request_timeout=_request_timeout,
                                           body=body)
        else:
            raise ValueError(
                "http method must be `GET`, `HEAD`, `OPTIONS`,"
                " `POST`, `PATCH`, `PUT` or `DELETE`."
            )

    def parameters_to_tuples(self, params, collection_formats):
        """
        Get parameters as list of tuples, formatting collections.

        :param params: Parameters as dict or list of two-tuples
        :param dict collection_formats: Parameter collection formats
        :return: Parameters as list of tuples, collections formatted
        """
        new_params = []
        if collection_formats is None:
            collection_formats = {}
        for k, v in iteritems(params) if isinstance(params, dict) else params:
            if k in collection_formats:
                collection_format = collection_formats[k]
                if collection_format == 'multi':
                    new_params.extend((k, value) for value in v)
                else:
                    if collection_format == 'ssv':
                        delimiter = ' '
                    elif collection_format == 'tsv':
                        delimiter = '\t'
                    elif collection_format == 'pipes':
                        delimiter = '|'
                    else:  # csv is the default
                        delimiter = ','
                    new_params.append(
                        (k, delimiter.join(str(value) for value in v)))
            else:
                new_params.append((k, v))
        return new_params

    def prepare_post_parameters(self, post_params=None, files=None):
        """
        Builds form parameters.

        :param post_params: Normal form parameters.
        :param files: File parameters.
        :return: Form parameters with files.
        """
        params = []

        if post_params:
            params = post_params

        if files:
            for k, v in iteritems(files):
                if not v:
                    continue
                file_names = v if type(v) is list else [v]
                for n in file_names:
                    with open(n, 'rb') as f:
                        filename = os.path.basename(f.name)
                        filedata = f.read()
                        mimetype = mimetypes.\
                            guess_type(filename)[0] or 'application/octet-stream'
                        params.append(tuple([k, tuple([filename, filedata, mimetype])]))

        return params

    def select_header_accept(self, accepts):
        """
        Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        if not accepts:
            return

        accepts = [x.lower() for x in accepts]

        if 'application/json' in accepts:
            return 'application/json'
        else:
            return ', '.join(accepts)

    def select_header_content_type(self, content_types):
        """
        Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return 'application/json'

        content_types = [x.lower() for x in content_types]

        if 'application/json' in content_types or '*/*' in content_types:
            return 'application/json'
        else:
            return content_types[0]

    def update_params_for_auth(self, headers, querys, auth_settings):
        """
        Updates header and query params based on authentication setting.

        :param headers: Header parameters dict to be updated.
        :param querys: Query parameters tuple list to be updated.
        :param auth_settings: Authentication setting identifiers list.
        """
        config = Configuration()

        if not auth_settings:
            return

        for auth in auth_settings:
            auth_setting = config.auth_settings().get(auth)
            if auth_setting:
                if not auth_setting['value']:
                    continue
                elif auth_setting['in'] == 'header':
                    headers[auth_setting['key']] = auth_setting['value']
                elif auth_setting['in'] == 'query':
                    querys.append((auth_setting['key'], auth_setting['value']))
                else:
                    raise ValueError(
                        'Authentication token must be in `query` or `header`'
                    )

    def __deserialize_file(self, response):
        """
        Saves response body into a file in a temporary folder,
        using the filename from the `Content-Disposition` header if provided.

        :param response:  RESTResponse.
        :return: file path.
        """
        config = Configuration()

        fd, path = tempfile.mkstemp(dir=config.temp_folder_path)
        os.close(fd)
        os.remove(path)

        content_disposition = response.getheader("Content-Disposition")
        if content_disposition:
            filename = re.\
                search(r'filename=[\'"]?([^\'"\s]+)[\'"]?', content_disposition).\
                group(1)
            curr_time = datetime.now()
            formatted_time = curr_time.strftime('%m%d%Y_%H%M%S_%f')
            filename = "{}_{}".format(formatted_time, filename)
            path = os.path.join(os.path.dirname(path), filename)

        with open(path, "wb") as f:
            f.write(response.data)

        return path

    def __deserialize_primitive(self, data, klass):
        """
        Deserializes string to primitive type.

        :param data: str.
        :param klass: class literal.

        :return: int, long, float, str, bool.
        """
        try:
            return klass(data)
        except UnicodeEncodeError:
            return unicode(data)
        except TypeError:
            return data

    def __deserialize_object(self, value):
        """
        Return a original value.

        :return: object.
        """
        return value

    def __deserialize_date(self, string):
        """
        Deserializes string to date.

        :param string: str.
        :return: date.
        """
        try:
            from dateutil.parser import parse
            return parse(string).date()
        except ImportError:
            return string
        except ValueError:
            raise ApiException(
                status=0,
                reason="Failed to parse `{0}` into a date object".format(string)
            )

    def __deserialize_datatime(self, string):
        """
        Deserializes string to datetime.

        The string should be in iso8601 datetime format.

        :param string: str.
        :return: datetime.
        """
        try:
            from dateutil.parser import parse
            return parse(string)
        except ImportError:
            return string
        except ValueError:
            raise ApiException(
                status=0,
                reason=(
                    "Failed to parse `{0}` into a datetime object"
                    .format(string)
                )
            )

    def __deserialize_model(self, data, klass):
        """
        Deserializes list or dict to model.

        :param data: dict, list.
        :param klass: class literal.
        :return: model object.
        """
        instance = klass()

        if not instance.swagger_types:
            return data

        for attr, attr_type in iteritems(instance.swagger_types):
            if data is not None \
               and instance.attribute_map[attr] in data \
               and isinstance(data, (list, dict)):
                value = data[instance.attribute_map[attr]]
                setattr(instance, attr, self.__deserialize(value, attr_type))

        return instance

    def request_jwt_user_token(self, client_id, user_id, oauth_host_name, private_key_bytes, expires_in,
                               scopes=(OAuth.SCOPE_SIGNATURE,)):
        """
        Request JWT User Token
        :param client_id: DocuSign OAuth Client Id(AKA Integrator Key)
        :param user_id: DocuSign user Id to be impersonated
        :param oauth_host_name: DocuSign OAuth host name
        :param private_key_bytes: the byte contents of the RSA private key
        :param expires_in: number of seconds remaining before the JWT assertion is considered as invalid
        :param scopes: Optional. The list of requested scopes may include (but not limited to) You can also pass any
        advanced scope.
        :return: OAuthToken object
        """
        if not private_key_bytes:
            raise ArgumentException("Private key not supplied or is invalid!")
        if not user_id:
            raise ArgumentException("User Id not supplied or is invalid!")
        if not oauth_host_name:
            raise ArgumentException("oAuthBasePath cannot be empty")

        now = math.floor(time())
        later = now + (expires_in * 1)
        claim = {"iss": client_id, "sub": user_id, "aud": oauth_host_name, "iat": now, "exp": later,
                 "scope": " ".join(scopes)}
        token = jwt.encode(payload=claim, key=private_key_bytes, algorithm='RS256')
        response = self.request("POST", "https://" + oauth_host_name + "/oauth/token",
                                headers=self.sanitize_for_serialization(
                                    {"Content-Type": "application/x-www-form-urlencoded"}),
                                post_params=self.sanitize_for_serialization(
                                    {"assertion": token, "grant_type": OAuth.GRANT_TYPE_JWT}))

        response_data = json.loads(response.data)

        if 'token_type' in response_data and 'access_token' in response_data:
            self.set_default_header("Authorization", response_data['token_type'] + " " + response_data['access_token'])
        else:
            raise ApiException(status=response.status,
                               reason="Error while requesting server, received a non successful HTTP code {}"
                                       " with response Body: {}".format(response.status, response.data)
                               )

        return self.deserialize(response=response, response_type=OAuthToken)

    def request_jwt_application_token(self, client_id, oauth_host_name, private_key_bytes, expires_in,
                                      scopes=(OAuth.SCOPE_SIGNATURE,)):
        """
        Request JWT Application Token
        :param client_id: DocuSign OAuth Client Id(AKA Integrator Key)
        :param oauth_host_name: DocuSign OAuth host name
        :param private_key_bytes: the byte contents of the RSA private key
        :param expires_in: number of seconds remaining before the JWT assertion is considered as invalid
        :param scopes: Optional. The list of requested scopes may include (but not limited to) You can also pass any
        advanced scope.
        :return: OAuthToken object
        """

        if not private_key_bytes:
            raise ArgumentException("Private key not supplied or is invalid!")
        if not oauth_host_name:
            raise ArgumentException("oAuthBasePath cannot be empty")

        now = math.floor(time())
        later = now + (expires_in * 1)
        claim = {"iss": client_id, "aud": oauth_host_name, "iat": now, "exp": later,
                 "scope": " ".join(scopes)}
        token = jwt.encode(payload=claim, key=private_key_bytes, algorithm='RS256')

        response = self.request("POST", "https://" + oauth_host_name + "/oauth/token",
                                headers=self.sanitize_for_serialization(
                                    {"Content-Type": "application/x-www-form-urlencoded"}),
                                post_params=self.sanitize_for_serialization(
                                    {"assertion": token, "grant_type": "urn:ietf:params:oauth:grant-type:jwt-bearer"}))
        response_data = json.loads(response.data)

        if 'token_type' in response_data and 'access_token' in response_data:
            self.set_default_header("Authorization", response_data['token_type'] + " " + response_data['access_token'])
        else:
            ApiException(status=response.status,
                         reason="Error while requesting server, received a non successful HTTP code {}"
                                " with response Body: {}".format(response.status, response.data)
                         )

        return self.deserialize(response=response, response_type=OAuthToken)

    def get_user_info(self, access_token):
        """
        Get User Info method takes the accessToken to retrieve User Account Data.
        :param access_token:
        :return: The User Info model.
        """
        if not access_token:
            raise ArgumentException("Cannot find a valid access token."
                                    " Make sure OAuth is configured before you try again.")
        if not self.oauth_host_name:
            raise ArgumentException("oAuthBasePath cannot be empty")

        resource_path = '/oauth/userinfo'
        headers = {"Authorization": "Bearer " + access_token}

        response = self.request("GET", "https://" + self.oauth_host_name + resource_path, headers=headers)
        return self.deserialize(response=response, response_type=OAuthUserInfo)

    def generate_access_token(self, client_id, client_secret, code):
        """
        GenerateAccessToken will exchange the authorization code for an access token and refresh tokens.
        :param client_id: DocuSign OAuth Client Id(AKA Integrator Key)
        :param client_secret: The secret key you generated when you set up the integration in DocuSign Admin console.
        :param code: The authorization code
        :return: OAuthToken object
        """
        if not client_id or not client_secret or not code:
            raise ArgumentException
        url = "https://{0}/oauth/token".format(self.oauth_host_name)
        integrator_and_secret_key = b"Basic " + base64.b64encode(str.encode("{}:{}".format(client_id, client_secret)))
        headers = {
            "Authorization": integrator_and_secret_key.decode("utf-8"),
            "Content-Type": "application/x-www-form-urlencoded",
        }
        post_params = self.sanitize_for_serialization({
            "grant_type": "authorization_code",
            "code": code
        })
        response = self.rest_client.POST(url, headers=headers, post_params=post_params)

        return self.deserialize(response=response, response_type=OAuthToken)

    def set_base_path(self, base_path):
        """
        :param base_path:
        :return:
        """
        self.base_path = base_path

    def set_oauth_host_name(self, oauth_host_name=None):
        """
        :param oauth_host_name:
        :return:
        """
        if oauth_host_name:
            self.oauth_host_name = oauth_host_name
            return

        # Derive OAuth Base Path if not given
        if self.base_path is None or self.base_path.startswith("https://demo") or self.base_path.startswith("http://demo") or self.base_path.startswith("https://apps-d") or self.base_path.startswith("http://apps-d"):
            self.oauth_host_name = OAuth.DEMO_OAUTH_BASE_PATH
        elif self.base_path.startswith("https://stage") or self.base_path.startswith("http://stage") or self.base_path.startswith("https://apps-s") or self.base_path.startswith("http://apps-s"):
            self.oauth_host_name = OAuth.STAGE_OAUTH_BASE_PATH
        else:
            self.oauth_host_name = OAuth.PRODUCTION_OAUTH_BASE_PATH

    def set_access_token(self, token_obj):
        """

        :param token_obj: 
        :return: 
        """
        self.default_headers['Authorization'] = token_obj.access_token

    def get_authorization_uri(self, client_id, scopes, redirect_uri, response_type, state=None):
        """
        Helper method to configure the OAuth accessCode/implicit flow parameters
        :param client_id: DocuSign OAuth Client Id(AKA Integrator Key)
        :param scopes: The list of requested scopes.  Client applications may be scoped to a limited set of system access.
        :param redirect_uri: This determines where to deliver the response containing the authorization code
        :param response_type: Determines the response type of the authorization request, NOTE: these response types are
        mutually exclusive for a client application. A public/native client application may only request a response type
         of "token". A private/trusted client application may only request a response type of "code".
        :param state: Allows for arbitrary state that may be useful to your application. The value in this parameter
        will be round-tripped along with the response so you can make sure it didn't change.
        :return: string
        """
        if not self.oauth_host_name:
            self.oauth_host_name = self.get_oauth_host_name()
        scopes = " ".join(scopes) if scopes else ""
        uri = "https://{}/oauth/auth?response_type={}&scope={}&client_id={}&redirect_uri={}"
        if state:
            uri += "&state={}"
        return uri.format(self.oauth_host_name, response_type, quote(scopes), client_id, redirect_uri, state)

    def get_oauth_host_name(self):
        """
        :return: string
        """
        if not self.oauth_host_name:
            self.set_oauth_host_name()

        return self.oauth_host_name



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class GetConfigurationInstanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'saved_values': 'object',
        'step_id': 'str',
        'workflow_definition_id': 'str'
    }

    attribute_map = {
        'saved_values': 'savedValues',
        'step_id': 'stepId',
        'workflow_definition_id': 'workflowDefinitionId'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """GetConfigurationInstanceResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._saved_values = None
        self._step_id = None
        self._workflow_definition_id = None
        self.discriminator = None

        setattr(self, "_{}".format('saved_values'), kwargs.get('saved_values', None))
        setattr(self, "_{}".format('step_id'), kwargs.get('step_id', None))
        setattr(self, "_{}".format('workflow_definition_id'), kwargs.get('workflow_definition_id', None))

    @property
    def saved_values(self):
        """Gets the saved_values of this GetConfigurationInstanceResponse.  # noqa: E501


        :return: The saved_values of this GetConfigurationInstanceResponse.  # noqa: E501
        :rtype: object
        """
        return self._saved_values

    @saved_values.setter
    def saved_values(self, saved_values):
        """Sets the saved_values of this GetConfigurationInstanceResponse.


        :param saved_values: The saved_values of this GetConfigurationInstanceResponse.  # noqa: E501
        :type: object
        """

        self._saved_values = saved_values

    @property
    def step_id(self):
        """Gets the step_id of this GetConfigurationInstanceResponse.  # noqa: E501


        :return: The step_id of this GetConfigurationInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """Sets the step_id of this GetConfigurationInstanceResponse.


        :param step_id: The step_id of this GetConfigurationInstanceResponse.  # noqa: E501
        :type: str
        """

        self._step_id = step_id

    @property
    def workflow_definition_id(self):
        """Gets the workflow_definition_id of this GetConfigurationInstanceResponse.  # noqa: E501


        :return: The workflow_definition_id of this GetConfigurationInstanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._workflow_definition_id

    @workflow_definition_id.setter
    def workflow_definition_id(self, workflow_definition_id):
        """Sets the workflow_definition_id of this GetConfigurationInstanceResponse.


        :param workflow_definition_id: The workflow_definition_id of this GetConfigurationInstanceResponse.  # noqa: E501
        :type: str
        """

        self._workflow_definition_id = workflow_definition_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetConfigurationInstanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetConfigurationInstanceResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetConfigurationInstanceResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DSWorkflowToUpperExpression(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'object',
        'type': 'DSWorkflowTransformationExpressionTypesToUpperExpression'
    }

    attribute_map = {
        'text': 'text',
        'type': 'type'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DSWorkflowToUpperExpression - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._text = None
        self._type = None
        self.discriminator = None

        setattr(self, "_{}".format('text'), kwargs.get('text', None))
        setattr(self, "_{}".format('type'), kwargs.get('type', None))

    @property
    def text(self):
        """Gets the text of this DSWorkflowToUpperExpression.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The text of this DSWorkflowToUpperExpression.  # noqa: E501
        :rtype: object
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this DSWorkflowToUpperExpression.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param text: The text of this DSWorkflowToUpperExpression.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def type(self):
        """Gets the type of this DSWorkflowToUpperExpression.  # noqa: E501


        :return: The type of this DSWorkflowToUpperExpression.  # noqa: E501
        :rtype: DSWorkflowTransformationExpressionTypesToUpperExpression
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DSWorkflowToUpperExpression.


        :param type: The type of this DSWorkflowToUpperExpression.  # noqa: E501
        :type: DSWorkflowTransformationExpressionTypesToUpperExpression
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DSWorkflowToUpperExpression, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DSWorkflowToUpperExpression):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DSWorkflowToUpperExpression):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class WorkflowDefinitionMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'created_date': 'datetime',
        'id': 'str',
        'is_draft': 'bool',
        'last_deployed_id': 'str',
        'last_deployed_version': 'str',
        'last_updated_date': 'datetime',
        'name': 'str',
        'status': 'WorkflowMetadataStatus',
        'trigger_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'created_date': 'createdDate',
        'id': 'id',
        'is_draft': 'isDraft',
        'last_deployed_id': 'lastDeployedId',
        'last_deployed_version': 'lastDeployedVersion',
        'last_updated_date': 'lastUpdatedDate',
        'name': 'name',
        'status': 'status',
        'trigger_url': 'triggerUrl'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """WorkflowDefinitionMetadata - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._created_date = None
        self._id = None
        self._is_draft = None
        self._last_deployed_id = None
        self._last_deployed_version = None
        self._last_updated_date = None
        self._name = None
        self._status = None
        self._trigger_url = None
        self.discriminator = None

        setattr(self, "_{}".format('account_id'), kwargs.get('account_id', None))
        setattr(self, "_{}".format('created_date'), kwargs.get('created_date', None))
        setattr(self, "_{}".format('id'), kwargs.get('id', None))
        setattr(self, "_{}".format('is_draft'), kwargs.get('is_draft', None))
        setattr(self, "_{}".format('last_deployed_id'), kwargs.get('last_deployed_id', None))
        setattr(self, "_{}".format('last_deployed_version'), kwargs.get('last_deployed_version', None))
        setattr(self, "_{}".format('last_updated_date'), kwargs.get('last_updated_date', None))
        setattr(self, "_{}".format('name'), kwargs.get('name', None))
        setattr(self, "_{}".format('status'), kwargs.get('status', None))
        setattr(self, "_{}".format('trigger_url'), kwargs.get('trigger_url', None))

    @property
    def account_id(self):
        """Gets the account_id of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The account_id of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WorkflowDefinitionMetadata.


        :param account_id: The account_id of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def created_date(self):
        """Gets the created_date of this WorkflowDefinitionMetadata.  # noqa: E501

        The date the workflow was created  # noqa: E501

        :return: The created_date of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this WorkflowDefinitionMetadata.

        The date the workflow was created  # noqa: E501

        :param created_date: The created_date of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def id(self):
        """Gets the id of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The id of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowDefinitionMetadata.


        :param id: The id of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_draft(self):
        """Gets the is_draft of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The is_draft of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_draft

    @is_draft.setter
    def is_draft(self, is_draft):
        """Sets the is_draft of this WorkflowDefinitionMetadata.


        :param is_draft: The is_draft of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: bool
        """

        self._is_draft = is_draft

    @property
    def last_deployed_id(self):
        """Gets the last_deployed_id of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The last_deployed_id of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._last_deployed_id

    @last_deployed_id.setter
    def last_deployed_id(self, last_deployed_id):
        """Sets the last_deployed_id of this WorkflowDefinitionMetadata.


        :param last_deployed_id: The last_deployed_id of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """

        self._last_deployed_id = last_deployed_id

    @property
    def last_deployed_version(self):
        """Gets the last_deployed_version of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The last_deployed_version of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._last_deployed_version

    @last_deployed_version.setter
    def last_deployed_version(self, last_deployed_version):
        """Sets the last_deployed_version of this WorkflowDefinitionMetadata.


        :param last_deployed_version: The last_deployed_version of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """

        self._last_deployed_version = last_deployed_version

    @property
    def last_updated_date(self):
        """Gets the last_updated_date of this WorkflowDefinitionMetadata.  # noqa: E501

        The date the workflow was last updated  # noqa: E501

        :return: The last_updated_date of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated_date

    @last_updated_date.setter
    def last_updated_date(self, last_updated_date):
        """Sets the last_updated_date of this WorkflowDefinitionMetadata.

        The date the workflow was last updated  # noqa: E501

        :param last_updated_date: The last_updated_date of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: datetime
        """

        self._last_updated_date = last_updated_date

    @property
    def name(self):
        """Gets the name of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The name of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowDefinitionMetadata.


        :param name: The name of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The status of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: WorkflowMetadataStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WorkflowDefinitionMetadata.


        :param status: The status of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: WorkflowMetadataStatus
        """

        self._status = status

    @property
    def trigger_url(self):
        """Gets the trigger_url of this WorkflowDefinitionMetadata.  # noqa: E501


        :return: The trigger_url of this WorkflowDefinitionMetadata.  # noqa: E501
        :rtype: str
        """
        return self._trigger_url

    @trigger_url.setter
    def trigger_url(self, trigger_url):
        """Sets the trigger_url of this WorkflowDefinitionMetadata.


        :param trigger_url: The trigger_url of this WorkflowDefinitionMetadata.  # noqa: E501
        :type: str
        """

        self._trigger_url = trigger_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowDefinitionMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowDefinitionMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowDefinitionMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class WorkflowInstance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'creator_id': 'str',
        'dac_id': 'str',
        'end_date': 'datetime',
        'instance_name': 'str',
        'instance_state': 'WorkflowInstanceState',
        'progress': 'ProgressInstance',
        'start_date': 'datetime',
        'started_by': 'StartedByInstance',
        'template_id': 'str',
        'users': 'dict(str, str)'
    }

    attribute_map = {
        'account_id': 'accountId',
        'creator_id': 'creatorId',
        'dac_id': 'dacId',
        'end_date': 'endDate',
        'instance_name': 'instanceName',
        'instance_state': 'instanceState',
        'progress': 'progress',
        'start_date': 'startDate',
        'started_by': 'startedBy',
        'template_id': 'templateId',
        'users': 'users'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """WorkflowInstance - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._creator_id = None
        self._dac_id = None
        self._end_date = None
        self._instance_name = None
        self._instance_state = None
        self._progress = None
        self._start_date = None
        self._started_by = None
        self._template_id = None
        self._users = None
        self.discriminator = None

        setattr(self, "_{}".format('account_id'), kwargs.get('account_id', None))
        setattr(self, "_{}".format('creator_id'), kwargs.get('creator_id', None))
        setattr(self, "_{}".format('dac_id'), kwargs.get('dac_id', None))
        setattr(self, "_{}".format('end_date'), kwargs.get('end_date', None))
        setattr(self, "_{}".format('instance_name'), kwargs.get('instance_name', None))
        setattr(self, "_{}".format('instance_state'), kwargs.get('instance_state', None))
        setattr(self, "_{}".format('progress'), kwargs.get('progress', None))
        setattr(self, "_{}".format('start_date'), kwargs.get('start_date', None))
        setattr(self, "_{}".format('started_by'), kwargs.get('started_by', None))
        setattr(self, "_{}".format('template_id'), kwargs.get('template_id', None))
        setattr(self, "_{}".format('users'), kwargs.get('users', None))

    @property
    def account_id(self):
        """Gets the account_id of this WorkflowInstance.  # noqa: E501


        :return: The account_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WorkflowInstance.


        :param account_id: The account_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def creator_id(self):
        """Gets the creator_id of this WorkflowInstance.  # noqa: E501


        :return: The creator_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this WorkflowInstance.


        :param creator_id: The creator_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and creator_id is None:
            raise ValueError("Invalid value for `creator_id`, must not be `None`")  # noqa: E501

        self._creator_id = creator_id

    @property
    def dac_id(self):
        """Gets the dac_id of this WorkflowInstance.  # noqa: E501


        :return: The dac_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._dac_id

    @dac_id.setter
    def dac_id(self, dac_id):
        """Sets the dac_id of this WorkflowInstance.


        :param dac_id: The dac_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and dac_id is None:
            raise ValueError("Invalid value for `dac_id`, must not be `None`")  # noqa: E501

        self._dac_id = dac_id

    @property
    def end_date(self):
        """Gets the end_date of this WorkflowInstance.  # noqa: E501

        Track the End time of the Workflow Instance  # noqa: E501

        :return: The end_date of this WorkflowInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this WorkflowInstance.

        Track the End time of the Workflow Instance  # noqa: E501

        :param end_date: The end_date of this WorkflowInstance.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def instance_name(self):
        """Gets the instance_name of this WorkflowInstance.  # noqa: E501

        The friendly name of the particular workflow instance  # noqa: E501

        :return: The instance_name of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this WorkflowInstance.

        The friendly name of the particular workflow instance  # noqa: E501

        :param instance_name: The instance_name of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_state(self):
        """Gets the instance_state of this WorkflowInstance.  # noqa: E501


        :return: The instance_state of this WorkflowInstance.  # noqa: E501
        :rtype: WorkflowInstanceState
        """
        return self._instance_state

    @instance_state.setter
    def instance_state(self, instance_state):
        """Sets the instance_state of this WorkflowInstance.


        :param instance_state: The instance_state of this WorkflowInstance.  # noqa: E501
        :type: WorkflowInstanceState
        """
        if self._configuration.client_side_validation and instance_state is None:
            raise ValueError("Invalid value for `instance_state`, must not be `None`")  # noqa: E501

        self._instance_state = instance_state

    @property
    def progress(self):
        """Gets the progress of this WorkflowInstance.  # noqa: E501


        :return: The progress of this WorkflowInstance.  # noqa: E501
        :rtype: ProgressInstance
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this WorkflowInstance.


        :param progress: The progress of this WorkflowInstance.  # noqa: E501
        :type: ProgressInstance
        """

        self._progress = progress

    @property
    def start_date(self):
        """Gets the start_date of this WorkflowInstance.  # noqa: E501

        Track the Start time of the Workflow Instance  # noqa: E501

        :return: The start_date of this WorkflowInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this WorkflowInstance.

        Track the Start time of the Workflow Instance  # noqa: E501

        :param start_date: The start_date of this WorkflowInstance.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def started_by(self):
        """Gets the started_by of this WorkflowInstance.  # noqa: E501


        :return: The started_by of this WorkflowInstance.  # noqa: E501
        :rtype: StartedByInstance
        """
        return self._started_by

    @started_by.setter
    def started_by(self, started_by):
        """Sets the started_by of this WorkflowInstance.


        :param started_by: The started_by of this WorkflowInstance.  # noqa: E501
        :type: StartedByInstance
        """

        self._started_by = started_by

    @property
    def template_id(self):
        """Gets the template_id of this WorkflowInstance.  # noqa: E501


        :return: The template_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this WorkflowInstance.


        :param template_id: The template_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and template_id is None:
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def users(self):
        """Gets the users of this WorkflowInstance.  # noqa: E501

        Contains the list of Users and Steps mapping  # noqa: E501

        :return: The users of this WorkflowInstance.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this WorkflowInstance.

        Contains the list of Users and Steps mapping  # noqa: E501

        :param users: The users of this WorkflowInstance.  # noqa: E501
        :type: dict(str, str)
        """
        if self._configuration.client_side_validation and users is None:
            raise ValueError("Invalid value for `users`, must not be `None`")  # noqa: E501

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowInstance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowInstance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowInstance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DeployResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'method': 'str',
        'poll_url': 'str',
        'received_time': 'datetime'
    }

    attribute_map = {
        'message': 'message',
        'method': 'method',
        'poll_url': 'pollUrl',
        'received_time': 'receivedTime'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DeployResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._message = None
        self._method = None
        self._poll_url = None
        self._received_time = None
        self.discriminator = None

        setattr(self, "_{}".format('message'), kwargs.get('message', None))
        setattr(self, "_{}".format('method'), kwargs.get('method', None))
        setattr(self, "_{}".format('poll_url'), kwargs.get('poll_url', None))
        setattr(self, "_{}".format('received_time'), kwargs.get('received_time', None))

    @property
    def message(self):
        """Gets the message of this DeployResponse.  # noqa: E501


        :return: The message of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeployResponse.


        :param message: The message of this DeployResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def method(self):
        """Gets the method of this DeployResponse.  # noqa: E501


        :return: The method of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this DeployResponse.


        :param method: The method of this DeployResponse.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def poll_url(self):
        """Gets the poll_url of this DeployResponse.  # noqa: E501


        :return: The poll_url of this DeployResponse.  # noqa: E501
        :rtype: str
        """
        return self._poll_url

    @poll_url.setter
    def poll_url(self, poll_url):
        """Sets the poll_url of this DeployResponse.


        :param poll_url: The poll_url of this DeployResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and poll_url is None:
            raise ValueError("Invalid value for `poll_url`, must not be `None`")  # noqa: E501

        self._poll_url = poll_url

    @property
    def received_time(self):
        """Gets the received_time of this DeployResponse.  # noqa: E501


        :return: The received_time of this DeployResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._received_time

    @received_time.setter
    def received_time(self, received_time):
        """Sets the received_time of this DeployResponse.


        :param received_time: The received_time of this DeployResponse.  # noqa: E501
        :type: datetime
        """

        self._received_time = received_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeployResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeployResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeployResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from docusign_maestro.models.access_token_response import AccessTokenResponse
from docusign_maestro.models.access_token_token_types import AccessTokenTokenTypes
from docusign_maestro.models.cancel_response import CancelResponse
from docusign_maestro.models.create_or_update_workflow_definition_request_body import CreateOrUpdateWorkflowDefinitionRequestBody
from docusign_maestro.models.ds_do_until_step import DSDoUntilStep
from docusign_maestro.models.ds_doc_gen_step import DSDocGenStep
from docusign_maestro.models.ds_doc_gen_step_input import DSDocGenStepInput
from docusign_maestro.models.ds_idv_step import DSIdvStep
from docusign_maestro.models.ds_idv_step_input import DSIdvStepInput
from docusign_maestro.models.ds_if_else_step import DSIfElseStep
from docusign_maestro.models.ds_loop_step import DSLoopStep
from docusign_maestro.models.ds_parallel_step import DSParallelStep
from docusign_maestro.models.ds_service_step import DSServiceStep
from docusign_maestro.models.ds_sign_step import DSSignStep
from docusign_maestro.models.ds_sign_step_input import DSSignStepInput
from docusign_maestro.models.ds_transformation_step import DSTransformationStep
from docusign_maestro.models.ds_web_forms_step import DSWebFormsStep
from docusign_maestro.models.ds_web_forms_step_config import DSWebFormsStepConfig
from docusign_maestro.models.ds_workflow_boolean_expression import DSWorkflowBooleanExpression
from docusign_maestro.models.ds_workflow_comparison_expression import DSWorkflowComparisonExpression
from docusign_maestro.models.ds_workflow_comparison_operator_types import DSWorkflowComparisonOperatorTypes
from docusign_maestro.models.ds_workflow_concat_expression import DSWorkflowConcatExpression
from docusign_maestro.models.ds_workflow_doc_gen_doc_output_format import DSWorkflowDocGenDocOutputFormat
from docusign_maestro.models.ds_workflow_expression_types_boolean_expression import DSWorkflowExpressionTypesBooleanExpression
from docusign_maestro.models.ds_workflow_expression_types_comparison_expression import DSWorkflowExpressionTypesComparisonExpression
from docusign_maestro.models.ds_workflow_expression_types_parallel_expression import DSWorkflowExpressionTypesParallelExpression
from docusign_maestro.models.ds_workflow_index_of_expression import DSWorkflowIndexOfExpression
from docusign_maestro.models.ds_workflow_lane import DSWorkflowLane
from docusign_maestro.models.ds_workflow_lanes_record import DSWorkflowLanesRecord
from docusign_maestro.models.ds_workflow_last_index_of_expression import DSWorkflowLastIndexOfExpression
from docusign_maestro.models.ds_workflow_logical_operator_types import DSWorkflowLogicalOperatorTypes
from docusign_maestro.models.ds_workflow_parallel_expression import DSWorkflowParallelExpression
from docusign_maestro.models.ds_workflow_participant_record import DSWorkflowParticipantRecord
from docusign_maestro.models.ds_workflow_replace_expression import DSWorkflowReplaceExpression
from docusign_maestro.models.ds_workflow_step import DSWorkflowStep
from docusign_maestro.models.ds_workflow_step_types_ds_doc_gen import DSWorkflowStepTypesDSDocGen
from docusign_maestro.models.ds_workflow_step_types_ds_idv import DSWorkflowStepTypesDSIdv
from docusign_maestro.models.ds_workflow_step_types_ds_if_else import DSWorkflowStepTypesDSIfElse
from docusign_maestro.models.ds_workflow_step_types_ds_sign import DSWorkflowStepTypesDSSign
from docusign_maestro.models.ds_workflow_step_types_ds_transformation import DSWorkflowStepTypesDSTransformation
from docusign_maestro.models.ds_workflow_step_types_ds_web_forms import DSWorkflowStepTypesDSWebForms
from docusign_maestro.models.ds_workflow_step_types_do_until import DSWorkflowStepTypesDoUntil
from docusign_maestro.models.ds_workflow_step_types_loop import DSWorkflowStepTypesLoop
from docusign_maestro.models.ds_workflow_step_types_parallel import DSWorkflowStepTypesParallel
from docusign_maestro.models.ds_workflow_substring_expression import DSWorkflowSubstringExpression
from docusign_maestro.models.ds_workflow_to_lower_expression import DSWorkflowToLowerExpression
from docusign_maestro.models.ds_workflow_to_upper_expression import DSWorkflowToUpperExpression
from docusign_maestro.models.ds_workflow_transformation_expression import DSWorkflowTransformationExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_concat_expression import DSWorkflowTransformationExpressionTypesConcatExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_index_of_expression import DSWorkflowTransformationExpressionTypesIndexOfExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_last_index_of_expression import DSWorkflowTransformationExpressionTypesLastIndexOfExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_replace_expression import DSWorkflowTransformationExpressionTypesReplaceExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_substring_expression import DSWorkflowTransformationExpressionTypesSubstringExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_to_lower_expression import DSWorkflowTransformationExpressionTypesToLowerExpression
from docusign_maestro.models.ds_workflow_transformation_expression_types_to_upper_expression import DSWorkflowTransformationExpressionTypesToUpperExpression
from docusign_maestro.models.ds_workflow_trigger import DSWorkflowTrigger
from docusign_maestro.models.ds_workflow_trigger_types import DSWorkflowTriggerTypes
from docusign_maestro.models.ds_workflow_variable import DSWorkflowVariable
from docusign_maestro.models.ds_workflow_variable_from_participant import DSWorkflowVariableFromParticipant
from docusign_maestro.models.ds_workflow_variable_from_step import DSWorkflowVariableFromStep
from docusign_maestro.models.ds_workflow_variable_from_variable import DSWorkflowVariableFromVariable
from docusign_maestro.models.ds_workflow_variable_record import DSWorkflowVariableRecord
from docusign_maestro.models.ds_workflow_variable_source_types_step import DSWorkflowVariableSourceTypesStep
from docusign_maestro.models.ds_workflow_variable_source_types_variable import DSWorkflowVariableSourceTypesVariable
from docusign_maestro.models.deploy_request import DeployRequest
from docusign_maestro.models.deploy_response import DeployResponse
from docusign_maestro.models.deploy_status import DeployStatus
from docusign_maestro.models.deployment_status import DeploymentStatus
from docusign_maestro.models.e_sign_document_from_e_sign_template import ESignDocumentFromESignTemplate
from docusign_maestro.models.e_sign_document_from_previous_step import ESignDocumentFromPreviousStep
from docusign_maestro.models.e_sign_document_types_from_ds_template import ESignDocumentTypesFromDSTemplate
from docusign_maestro.models.e_sign_document_types_from_previous_step import ESignDocumentTypesFromPreviousStep
from docusign_maestro.models.e_sign_documents import ESignDocuments
from docusign_maestro.models.e_sign_locale_policy import ESignLocalePolicy
from docusign_maestro.models.e_sign_signer import ESignSigner
from docusign_maestro.models.e_sign_tabs import ESignTabs
from docusign_maestro.models.e_sign_tabs_record import ESignTabsRecord
from docusign_maestro.models.error_codes import ErrorCodes
from docusign_maestro.models.error_response import ErrorResponse
from docusign_maestro.models.event_types import EventTypes
from docusign_maestro.models.get_configuration_instance_response import GetConfigurationInstanceResponse
from docusign_maestro.models.get_configuration_instances_response import GetConfigurationInstancesResponse
from docusign_maestro.models.get_configuration_instances_response_config_instances import GetConfigurationInstancesResponseConfigInstances
from docusign_maestro.models.http_types import HttpTypes
from docusign_maestro.models.invalid_workflow_response import InvalidWorkflowResponse
from docusign_maestro.models.new_or_updated_workflow_definition_response import NewOrUpdatedWorkflowDefinitionResponse
from docusign_maestro.models.number_or_variable import NumberOrVariable
from docusign_maestro.models.participant import Participant
from docusign_maestro.models.progress_instance import ProgressInstance
from docusign_maestro.models.record_string_boolean import RecordStringBoolean
from docusign_maestro.models.record_string_or_variable_or_transformation import RecordStringOrVariableOrTransformation
from docusign_maestro.models.record_to_never import RecordToNever
from docusign_maestro.models.replication_status import ReplicationStatus
from docusign_maestro.models.started_by_instance import StartedByInstance
from docusign_maestro.models.string_or_variable_or_transformation import StringOrVariableOrTransformation
from docusign_maestro.models.success_message_response import SuccessMessageResponse
from docusign_maestro.models.trigger_payload import TriggerPayload
from docusign_maestro.models.trigger_workflow_via_post_response import TriggerWorkflowViaPostResponse
from docusign_maestro.models.validation_errors import ValidationErrors
from docusign_maestro.models.workflow_definition import WorkflowDefinition
from docusign_maestro.models.workflow_definition_list import WorkflowDefinitionList
from docusign_maestro.models.workflow_definition_metadata import WorkflowDefinitionMetadata
from docusign_maestro.models.workflow_definition_with_id import WorkflowDefinitionWithId
from docusign_maestro.models.workflow_delete_response import WorkflowDeleteResponse
from docusign_maestro.models.workflow_instance import WorkflowInstance
from docusign_maestro.models.workflow_instance_map import WorkflowInstanceMap
from docusign_maestro.models.workflow_instance_state import WorkflowInstanceState
from docusign_maestro.models.workflow_instances_list import WorkflowInstancesList
from docusign_maestro.models.workflow_metadata_status import WorkflowMetadataStatus
from docusign_maestro.models.workflow_step_error import WorkflowStepError
from docusign_maestro.models.workflow_step_error_error import WorkflowStepErrorError
from docusign_maestro.models.workflow_step_history import WorkflowStepHistory
from docusign_maestro.models.workflow_step_history_list import WorkflowStepHistoryList
from docusign_maestro.models.workflow_step_history_state import WorkflowStepHistoryState



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class ProgressInstance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'completed_steps': 'float',
        'current_completed_step_name': 'str',
        'total_steps': 'float'
    }

    attribute_map = {
        'completed_steps': 'completedSteps',
        'current_completed_step_name': 'currentCompletedStepName',
        'total_steps': 'totalSteps'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """ProgressInstance - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._completed_steps = None
        self._current_completed_step_name = None
        self._total_steps = None
        self.discriminator = None

        setattr(self, "_{}".format('completed_steps'), kwargs.get('completed_steps', None))
        setattr(self, "_{}".format('current_completed_step_name'), kwargs.get('current_completed_step_name', None))
        setattr(self, "_{}".format('total_steps'), kwargs.get('total_steps', None))

    @property
    def completed_steps(self):
        """Gets the completed_steps of this ProgressInstance.  # noqa: E501

        The number of completed steps for this workflow instance  # noqa: E501

        :return: The completed_steps of this ProgressInstance.  # noqa: E501
        :rtype: float
        """
        return self._completed_steps

    @completed_steps.setter
    def completed_steps(self, completed_steps):
        """Sets the completed_steps of this ProgressInstance.

        The number of completed steps for this workflow instance  # noqa: E501

        :param completed_steps: The completed_steps of this ProgressInstance.  # noqa: E501
        :type: float
        """

        self._completed_steps = completed_steps

    @property
    def current_completed_step_name(self):
        """Gets the current_completed_step_name of this ProgressInstance.  # noqa: E501

        The last completed step name  # noqa: E501

        :return: The current_completed_step_name of this ProgressInstance.  # noqa: E501
        :rtype: str
        """
        return self._current_completed_step_name

    @current_completed_step_name.setter
    def current_completed_step_name(self, current_completed_step_name):
        """Sets the current_completed_step_name of this ProgressInstance.

        The last completed step name  # noqa: E501

        :param current_completed_step_name: The current_completed_step_name of this ProgressInstance.  # noqa: E501
        :type: str
        """

        self._current_completed_step_name = current_completed_step_name

    @property
    def total_steps(self):
        """Gets the total_steps of this ProgressInstance.  # noqa: E501

        The total number of steps for this workflow instance  # noqa: E501

        :return: The total_steps of this ProgressInstance.  # noqa: E501
        :rtype: float
        """
        return self._total_steps

    @total_steps.setter
    def total_steps(self, total_steps):
        """Sets the total_steps of this ProgressInstance.

        The total number of steps for this workflow instance  # noqa: E501

        :param total_steps: The total_steps of this ProgressInstance.  # noqa: E501
        :type: float
        """

        self._total_steps = total_steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProgressInstance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressInstance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProgressInstance):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from .workflow_instance_management_api import WorkflowInstanceManagementApi
from .workflow_management_api import WorkflowManagementApi
from .workflow_trigger_api import WorkflowTriggerApi



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class ESignTabsRecord(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date_signed_tabs': 'list[ESignTabs]',
        'email_address_tabs': 'list[ESignTabs]',
        'first_name_tabs': 'list[ESignTabs]',
        'full_name_tabs': 'list[ESignTabs]',
        'last_name_tabs': 'list[ESignTabs]',
        'sign_here_tabs': 'list[ESignTabs]',
        'text_tabs': 'list[ESignTabs]'
    }

    attribute_map = {
        'date_signed_tabs': 'dateSignedTabs',
        'email_address_tabs': 'emailAddressTabs',
        'first_name_tabs': 'firstNameTabs',
        'full_name_tabs': 'fullNameTabs',
        'last_name_tabs': 'lastNameTabs',
        'sign_here_tabs': 'signHereTabs',
        'text_tabs': 'textTabs'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """ESignTabsRecord - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._date_signed_tabs = None
        self._email_address_tabs = None
        self._first_name_tabs = None
        self._full_name_tabs = None
        self._last_name_tabs = None
        self._sign_here_tabs = None
        self._text_tabs = None
        self.discriminator = None

        setattr(self, "_{}".format('date_signed_tabs'), kwargs.get('date_signed_tabs', None))
        setattr(self, "_{}".format('email_address_tabs'), kwargs.get('email_address_tabs', None))
        setattr(self, "_{}".format('first_name_tabs'), kwargs.get('first_name_tabs', None))
        setattr(self, "_{}".format('full_name_tabs'), kwargs.get('full_name_tabs', None))
        setattr(self, "_{}".format('last_name_tabs'), kwargs.get('last_name_tabs', None))
        setattr(self, "_{}".format('sign_here_tabs'), kwargs.get('sign_here_tabs', None))
        setattr(self, "_{}".format('text_tabs'), kwargs.get('text_tabs', None))

    @property
    def date_signed_tabs(self):
        """Gets the date_signed_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The date_signed_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._date_signed_tabs

    @date_signed_tabs.setter
    def date_signed_tabs(self, date_signed_tabs):
        """Sets the date_signed_tabs of this ESignTabsRecord.


        :param date_signed_tabs: The date_signed_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._date_signed_tabs = date_signed_tabs

    @property
    def email_address_tabs(self):
        """Gets the email_address_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The email_address_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._email_address_tabs

    @email_address_tabs.setter
    def email_address_tabs(self, email_address_tabs):
        """Sets the email_address_tabs of this ESignTabsRecord.


        :param email_address_tabs: The email_address_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._email_address_tabs = email_address_tabs

    @property
    def first_name_tabs(self):
        """Gets the first_name_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The first_name_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._first_name_tabs

    @first_name_tabs.setter
    def first_name_tabs(self, first_name_tabs):
        """Sets the first_name_tabs of this ESignTabsRecord.


        :param first_name_tabs: The first_name_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._first_name_tabs = first_name_tabs

    @property
    def full_name_tabs(self):
        """Gets the full_name_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The full_name_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._full_name_tabs

    @full_name_tabs.setter
    def full_name_tabs(self, full_name_tabs):
        """Sets the full_name_tabs of this ESignTabsRecord.


        :param full_name_tabs: The full_name_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._full_name_tabs = full_name_tabs

    @property
    def last_name_tabs(self):
        """Gets the last_name_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The last_name_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._last_name_tabs

    @last_name_tabs.setter
    def last_name_tabs(self, last_name_tabs):
        """Sets the last_name_tabs of this ESignTabsRecord.


        :param last_name_tabs: The last_name_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._last_name_tabs = last_name_tabs

    @property
    def sign_here_tabs(self):
        """Gets the sign_here_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The sign_here_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._sign_here_tabs

    @sign_here_tabs.setter
    def sign_here_tabs(self, sign_here_tabs):
        """Sets the sign_here_tabs of this ESignTabsRecord.


        :param sign_here_tabs: The sign_here_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._sign_here_tabs = sign_here_tabs

    @property
    def text_tabs(self):
        """Gets the text_tabs of this ESignTabsRecord.  # noqa: E501


        :return: The text_tabs of this ESignTabsRecord.  # noqa: E501
        :rtype: list[ESignTabs]
        """
        return self._text_tabs

    @text_tabs.setter
    def text_tabs(self, text_tabs):
        """Sets the text_tabs of this ESignTabsRecord.


        :param text_tabs: The text_tabs of this ESignTabsRecord.  # noqa: E501
        :type: list[ESignTabs]
        """

        self._text_tabs = text_tabs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ESignTabsRecord, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ESignTabsRecord):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ESignTabsRecord):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DSSignStepInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'documents': 'list[object]',
        'email_blurb': 'object',
        'email_subject': 'object',
        'is_embedded_sign': 'bool',
        'signers': 'list[ESignSigner]'
    }

    attribute_map = {
        'documents': 'documents',
        'email_blurb': 'emailBlurb',
        'email_subject': 'emailSubject',
        'is_embedded_sign': 'isEmbeddedSign',
        'signers': 'signers'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DSSignStepInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._documents = None
        self._email_blurb = None
        self._email_subject = None
        self._is_embedded_sign = None
        self._signers = None
        self.discriminator = None

        setattr(self, "_{}".format('documents'), kwargs.get('documents', None))
        setattr(self, "_{}".format('email_blurb'), kwargs.get('email_blurb', None))
        setattr(self, "_{}".format('email_subject'), kwargs.get('email_subject', None))
        setattr(self, "_{}".format('is_embedded_sign'), kwargs.get('is_embedded_sign', None))
        setattr(self, "_{}".format('signers'), kwargs.get('signers', None))

    @property
    def documents(self):
        """Gets the documents of this DSSignStepInput.  # noqa: E501

        A list of #/definitions/ESignDocuments. Each element is: ESignDocument Object. This object should be any of the following object models: [#/definitions/ESignDocumentFromPreviousStep, #/definitions/ESignDocumentFromESignTemplate]  # noqa: E501

        :return: The documents of this DSSignStepInput.  # noqa: E501
        :rtype: list[object]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """Sets the documents of this DSSignStepInput.

        A list of #/definitions/ESignDocuments. Each element is: ESignDocument Object. This object should be any of the following object models: [#/definitions/ESignDocumentFromPreviousStep, #/definitions/ESignDocumentFromESignTemplate]  # noqa: E501

        :param documents: The documents of this DSSignStepInput.  # noqa: E501
        :type: list[object]
        """
        if self._configuration.client_side_validation and documents is None:
            raise ValueError("Invalid value for `documents`, must not be `None`")  # noqa: E501

        self._documents = documents

    @property
    def email_blurb(self):
        """Gets the email_blurb of this DSSignStepInput.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The email_blurb of this DSSignStepInput.  # noqa: E501
        :rtype: object
        """
        return self._email_blurb

    @email_blurb.setter
    def email_blurb(self, email_blurb):
        """Sets the email_blurb of this DSSignStepInput.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param email_blurb: The email_blurb of this DSSignStepInput.  # noqa: E501
        :type: object
        """

        self._email_blurb = email_blurb

    @property
    def email_subject(self):
        """Gets the email_subject of this DSSignStepInput.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The email_subject of this DSSignStepInput.  # noqa: E501
        :rtype: object
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this DSSignStepInput.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param email_subject: The email_subject of this DSSignStepInput.  # noqa: E501
        :type: object
        """

        self._email_subject = email_subject

    @property
    def is_embedded_sign(self):
        """Gets the is_embedded_sign of this DSSignStepInput.  # noqa: E501


        :return: The is_embedded_sign of this DSSignStepInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_embedded_sign

    @is_embedded_sign.setter
    def is_embedded_sign(self, is_embedded_sign):
        """Sets the is_embedded_sign of this DSSignStepInput.


        :param is_embedded_sign: The is_embedded_sign of this DSSignStepInput.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_embedded_sign is None:
            raise ValueError("Invalid value for `is_embedded_sign`, must not be `None`")  # noqa: E501

        self._is_embedded_sign = is_embedded_sign

    @property
    def signers(self):
        """Gets the signers of this DSSignStepInput.  # noqa: E501


        :return: The signers of this DSSignStepInput.  # noqa: E501
        :rtype: list[ESignSigner]
        """
        return self._signers

    @signers.setter
    def signers(self, signers):
        """Sets the signers of this DSSignStepInput.


        :param signers: The signers of this DSSignStepInput.  # noqa: E501
        :type: list[ESignSigner]
        """
        if self._configuration.client_side_validation and signers is None:
            raise ValueError("Invalid value for `signers`, must not be `None`")  # noqa: E501

        self._signers = signers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DSSignStepInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DSSignStepInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DSSignStepInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class ESignSigner(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'object',
        'note': 'object',
        'routing_order': 'str',
        'tabs': 'ESignTabsRecord',
        'user_name': 'object'
    }

    attribute_map = {
        'email': 'email',
        'note': 'note',
        'routing_order': 'routingOrder',
        'tabs': 'tabs',
        'user_name': 'userName'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """ESignSigner - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._note = None
        self._routing_order = None
        self._tabs = None
        self._user_name = None
        self.discriminator = None

        setattr(self, "_{}".format('email'), kwargs.get('email', None))
        setattr(self, "_{}".format('note'), kwargs.get('note', None))
        setattr(self, "_{}".format('routing_order'), kwargs.get('routing_order', None))
        setattr(self, "_{}".format('tabs'), kwargs.get('tabs', None))
        setattr(self, "_{}".format('user_name'), kwargs.get('user_name', None))

    @property
    def email(self):
        """Gets the email of this ESignSigner.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The email of this ESignSigner.  # noqa: E501
        :rtype: object
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ESignSigner.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param email: The email of this ESignSigner.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def note(self):
        """Gets the note of this ESignSigner.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The note of this ESignSigner.  # noqa: E501
        :rtype: object
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ESignSigner.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param note: The note of this ESignSigner.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and note is None:
            raise ValueError("Invalid value for `note`, must not be `None`")  # noqa: E501

        self._note = note

    @property
    def routing_order(self):
        """Gets the routing_order of this ESignSigner.  # noqa: E501


        :return: The routing_order of this ESignSigner.  # noqa: E501
        :rtype: str
        """
        return self._routing_order

    @routing_order.setter
    def routing_order(self, routing_order):
        """Sets the routing_order of this ESignSigner.


        :param routing_order: The routing_order of this ESignSigner.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and routing_order is None:
            raise ValueError("Invalid value for `routing_order`, must not be `None`")  # noqa: E501

        self._routing_order = routing_order

    @property
    def tabs(self):
        """Gets the tabs of this ESignSigner.  # noqa: E501


        :return: The tabs of this ESignSigner.  # noqa: E501
        :rtype: ESignTabsRecord
        """
        return self._tabs

    @tabs.setter
    def tabs(self, tabs):
        """Sets the tabs of this ESignSigner.


        :param tabs: The tabs of this ESignSigner.  # noqa: E501
        :type: ESignTabsRecord
        """
        if self._configuration.client_side_validation and tabs is None:
            raise ValueError("Invalid value for `tabs`, must not be `None`")  # noqa: E501

        self._tabs = tabs

    @property
    def user_name(self):
        """Gets the user_name of this ESignSigner.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The user_name of this ESignSigner.  # noqa: E501
        :rtype: object
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ESignSigner.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param user_name: The user_name of this ESignSigner.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and user_name is None:
            raise ValueError("Invalid value for `user_name`, must not be `None`")  # noqa: E501

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ESignSigner, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ESignSigner):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ESignSigner):
            return True

        return self.to_dict() != other.to_dict()
